# Copyright (C) 2023 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


BOOKING_SCHEMA = {
    'type': 'object',
    'properties': {
        'child_id': {
            'type': 'string',
            'minLength': 1,
            'maxLength': 8,
        },
        'booking_list': {
            'type': 'array',
            'items': {
                'type': 'string',
                'pattern': '[A-Za-z0-9]+:[- A-Za-z0-9]+:[0-9]{4}-[0-9]{2}-[0-9]{2}',
            },
        },
        'start_date': {
            'type': 'string',
            'pattern': '^[0-9]{4}-[0-9]{2}-[0-9]{2}$',
        },
        'end_date': {
            'type': 'string',
            'pattern': '^[0-9]{4}-[0-9]{2}-[0-9]{2}$',
        },
    },
    'required': [
        'child_id',
        'booking_list',
        'start_date',
        'end_date',
    ],
}

SUBSCRIPTION_SCHEMA = {
    'type': 'object',
    'properties': {
        'person_id': {
            'type': 'string',
            'minLength': 1,
            'maxLength': 8,
        },
        'activity_id': {
            'type': 'string',
            'pattern': '[A-Za-z0-9]+',
        },
        'unit_id': {
            'type': 'string',
            'pattern': '[A-Za-z0-9]+',
        },
        'place_id': {
            'type': 'string',
            'pattern': '[A-Za-z0-9]+',
        },
        'start_date': {
            'type': 'string',
            'pattern': '^[0-9]{4}-[0-9]{2}-[0-9]{2}$',
        },
        'end_date': {
            'type': 'string',
            'pattern': '^[0-9]{4}-[0-9]{2}-[0-9]{2}$',
        },
    },
    'required': [
        'person_id',
        'activity_id',
        'unit_id',
        'place_id',
        'start_date',
        'end_date',
    ],
}

DELETE_BASKET_LINE_SCHEMA = {
    'type': 'object',
    'properties': {
        'line_id': {
            'type': 'string',
            'pattern': '[A-Za-z0-9]+',
        },
    },
    'required': [
        'line_id',
    ],
}
